@@ -70,6 +70,11 @@ class Fpm:
     # Handle extra_deps
     extra_deps = [v for dep in extra_deps for v in ('--depends', dep.replace('local', '', 1))]
 
+    # Handle install_path
+    install_path = '/opt/o2/'
+    if name == 'mesos':
+        install_path = '/usr/'
+
     packageName = self.packagePrefix + name
     fpmCommand = ['fpm',
       '-s', rpmType,
@@ -80,7 +85,7 @@ class Fpm:
       *self.forceBuild,
       '-p', self.targetDir,
       '--architecture', self.architecture,
-      '--prefix', '/opt/o2/',
+      '--prefix', install_path,
       '-n', packageName,
       '--version', version,
       *iterationArg,
@@ -90,7 +95,7 @@ class Fpm:
       '--after-remove', os.path.join(config.work_dir, 'after_remove_template.sh')]
 
     if paths:
-        fpmCommand.extend(['--exclude=*/modulefiles', '--exclude=*/profile.d'])
+        fpmCommand.extend(['--exclude=*/modulefiles', '--exclude=*/profile.d', '--exclude=*/info/dir', '--exclude=*/version'])
         fpmCommand.extend(paths)
 
     develPackageName = packageName + '-devel'
